@@ -1,5 +1,6 @@
 import os
 import csv
+from collections import namedtuple
 
 from unittest import TestCase
 from pyramid import testing
@@ -10,7 +11,14 @@ import pyramid_scss
 
 class PyramidScssTestCase(TestCase):
     scss_settings = {
-        'scss.asset_path': 'pyramid_scss.tests:fixtures',
+        'scss.asset_path': """
+            pyramid_scss.tests:fixtures
+            pyramid_scss.tests:fixtures/resources
+        """,
+        'scss.static_path': 'pyramid_scss.tests:fixtures/static',
+        'scss.static_url_root': '/static/',
+        'scss.output_path': 'pyramid_scss.tests:fixtures/compiled',
+        'scss.output_url_root': '/compiled/',
         'scss.cache': True,
     }
 
@@ -34,4 +42,4 @@ class DummyRequest(object):
     def __init__(self, registry):
         self.registry = registry
         self.matchdict = {}
-        self.response_content_type = None
+        self.response = namedtuple('Response', ['content_type'])
